==> haskell-data-array-byte-0.1.0.1-85-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-array-byte.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:               data-array-byte
version:            0.1.0.1
visibility:         public
id:                 data-array-byte-0.1.0.1-Bt0taN4jnmd7l3ZyBTlQA6
key:                data-array-byte-0.1.0.1-Bt0taN4jnmd7l3ZyBTlQA6
license:            BSD-3-Clause
copyright:          (c) Roman Leshchinskiy 2009-2012
maintainer:         andrew.lelechenko@gmail.com
author:             Roman Leshchinskiy <rl@cse.unsw.edu.au>
homepage:           https://github.com/Bodigrim/data-array-byte
synopsis:           Compatibility layer for Data.Array.Byte
description:
    Compatibility layer for [Data.Array.Byte](https://hackage.haskell.org/package/base/docs/Data-Array-Byte.html), providing boxed wrappers for @ByteArray#@ and @MutableByteArray#@ and relevant instances for GHC < 9.4. Include it into your Cabal file:

    > build-depends: base
    > if impl(ghc < 9.4)
    >   build-depends: data-array-byte

    and then @import Data.Array.Byte@ unconditionally.

category:           Compatibility
abi:                12d776480acf79c658d9432f8261bf55
exposed:            True
data-dir:           /usr/share/haskell-data-array-byte
depends:            base-4.17.2.1 deepseq-1.4.8.0 template-haskell-2.19.0.0
haddock-interfaces:
    /usr/share/doc/haskell-data-array-byte/html/data-array-byte.haddock

haddock-html:       /usr/share/doc/haskell-data-array-byte/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-array-byte-0.1.0.1-87-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-array-byte.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:               data-array-byte
version:            0.1.0.1
visibility:         public
id:                 data-array-byte-0.1.0.1-LwsIf9V74yFyvH1Wy4XHs
key:                data-array-byte-0.1.0.1-LwsIf9V74yFyvH1Wy4XHs
license:            BSD-3-Clause
copyright:          (c) Roman Leshchinskiy 2009-2012
maintainer:         andrew.lelechenko@gmail.com
author:             Roman Leshchinskiy <rl@cse.unsw.edu.au>
homepage:           https://github.com/Bodigrim/data-array-byte
synopsis:           Compatibility layer for Data.Array.Byte
description:
    Compatibility layer for [Data.Array.Byte](https://hackage.haskell.org/package/base/docs/Data-Array-Byte.html), providing boxed wrappers for @ByteArray#@ and @MutableByteArray#@ and relevant instances for GHC < 9.4. Include it into your Cabal file:

    > build-depends: base
    > if impl(ghc < 9.4)
    >   build-depends: data-array-byte

    and then @import Data.Array.Byte@ unconditionally.

category:           Compatibility
abi:                12d776480acf79c658d9432f8261bf55
exposed:            True
data-dir:           /usr/share/haskell-data-array-byte
depends:            base-4.17.2.1 deepseq-1.4.8.0 template-haskell-2.19.0.0
haddock-interfaces:
    /usr/share/doc/haskell-data-array-byte/html/data-array-byte.haddock

haddock-html:       /usr/share/doc/haskell-data-array-byte/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
